@@ -3,6 +3,7 @@ from lxml import html
 from . import helpers
 from . import util
 from .messaging import ThreadFetcher
+from .photo import PhotoUploader
 from .profile import Profile
 from .search import SearchManager
 from .session import Session
@@ -29,7 +30,7 @@ class User(object):
         self.outbox = util.Fetchable(ThreadFetcher(self._session, 2))
         self.drafts = util.Fetchable(ThreadFetcher(self._session, 4))
 
-    def get_user(self, username):
+    def get_profile(self, username):
         return Profile(self._session, username)
 
     _visitors_xpb = xpb.div.with_class('user_info').\
@@ -76,5 +77,9 @@ class User(object):
         response = self._session.okc_get('quickmatch', params={'okc_api': 1})
         return Profile(self._session, response.json()['sn'])
 
+    def upload_photo(self, filename):
+        return PhotoUploader(filename, self._session,
+                             user_id=self.profile._current_user_id)
+
     def __repr__(self):
         return 'User("{0}")'.format(self.profile.username)
